@@ -463,7 +463,7 @@ class ExecutionServer(BaseServer):
                 uuid_limit_clause)
         self.current_sql = sql
         LOGGER.debug("Querying SimpleDB, \"%s\"" % sql)
-        d = self.sdb.select(sql, max_results=self.reservation_check_interval * 20)
+        d = self.sdb.select(sql, max_results=self.reservation_check_interval * 30)
         d.addCallback(self._queryCallback)
         d.addErrback(self._queryErrback)
 
@@ -478,8 +478,6 @@ class ExecutionServer(BaseServer):
         for uuid in data:
             if uuid in self.active_jobs or uuid in self.queued_jobs:
                 continue
-            if len(self.job_queue) > self.reservation_check_interval * 20:
-                break
             kwargs_raw = {}
             reserved_arguments = {}
             # Load attributes into dicts for use by the system or custom functions.
@@ -552,7 +550,7 @@ class ExecutionServer(BaseServer):
             LOGGER.critical("No average speed to report yet.")
             
     def executeJobs(self, data=None):
-        for i in range(0, 10):            
+        for i in range(0, 100):            
             if len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
                 job = self.job_queue.pop(0)
                 exposed_function = job["exposed_function"]
@@ -561,16 +559,18 @@ class ExecutionServer(BaseServer):
                 uuid = job["uuid"]
                 del self.queued_jobs[uuid]
                 LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
-                self._callExposedFunction(
-                    exposed_function["function"],
-                    exposed_function["interval"], 
+                d = self.callExposedFunction(
+                    exposed_function["function"], 
                     kwargs, 
                     function_name, 
                     uuid=uuid,
                     reservation_fast_cache=job["reservation_cache"])
+                d.addCallback(self._jobCountCallback)
+                d.addErrback(self._jobCountErrback)
+                d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
             else:
                 return
-        reactor.callLater(.1, self.executeJobs)
+        reactor.callLater(0, self.executeJobs)
             
     def _callExposedFunction(
         self, 
@@ -586,9 +586,7 @@ class ExecutionServer(BaseServer):
             function_name, 
             uuid=uuid,
             reservation_fast_cache=reservation_fast_cache)
-        d.addCallback(self._jobCountCallback)
-        d.addErrback(self._jobCountErrback)
-        d.addCallback(self._setNextRequest, uuid, interval, function_name)
+
         
     def _jobCountCallback(self, data=None):
         self.job_count += 1
